@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.59';
+our $VERSION = '0.5901';
 
 use warnings;
 use strict;
@@ -11,7 +11,6 @@ use strict;
 use parent qw(Graph);
 
 use Readonly;
-Readonly my $DEBUG  => 0;
 Readonly my $WEIGHT => 'weight';
 
 
@@ -25,7 +24,6 @@ sub new {
 
 sub populate {
     my ($self, $data, $attr) = @_;
-    warn "populate(): $data\n" if $DEBUG;
 
     # Set the default attribute.
     $attr ||= $WEIGHT;
@@ -36,7 +34,6 @@ sub populate {
     if ($data_ref eq 'ARRAY' || $data_ref eq 'Math::Matrix') {
         my $vertex = 0; # Initial vertex id.
         for my $neighbors (@$data) {
-            warn "Neighbors of $vertex: [@$neighbors]\n" if $DEBUG;
             $self->_from_array(
                 $vertex, $neighbors, $attr
             );
@@ -49,7 +46,6 @@ sub populate {
                 my $label = delete $data->{$vertex}{label};
                 $self->set_vertex_attribute($vertex, 'label', $label);
             }
-            warn "Neighbors of $vertex: [", join(' ', values %{$data->{$vertex}}), "]\n" if $DEBUG && ref $vertex;
             $self->_from_hash(
                 $vertex, $data->{$vertex}, $attr
             );
@@ -62,7 +58,6 @@ sub populate {
 
 sub _from_array {
     my ($self, $vertex, $neighbors, $attr) = @_;
-    warn "add_weighted_edges(): $vertex, $neighbors, $attr\n" if $DEBUG;
 
     # Initial vertex weight
     my $vertex_weight = 0;
@@ -75,7 +70,6 @@ sub _from_array {
         # Add a node-node edge to the graph.
         $self->add_edge($vertex, $n);
 
-        warn "Edge: $vertex -($w)-> $n\n" if $DEBUG;
         $self->set_edge_attribute($vertex, $n, $attr, $w);
 
         # Tally the weight of the vertex.
@@ -83,13 +77,11 @@ sub _from_array {
     }
 
     # Set the weight of the graph node.
-    warn "Vertex $vertex $attr = $vertex_weight\n" if $DEBUG;
     $self->set_vertex_attribute($vertex, $attr, $vertex_weight);
 }
 
 sub _from_hash {
     my ($self, $vertex, $neighbors, $attr) = @_;
-    warn "add_weighted_edges(): $vertex, $neighbors, $attr\n" if $DEBUG;
 
     # Initial vertex weight
     my $vertex_weight = 0;
@@ -103,7 +95,6 @@ sub _from_hash {
             # Add a node-node edge to the graph.
             $self->add_edge($vertex, $n);
 
-            warn "Edge: $vertex -($w)-> $n\n" if $DEBUG;
             $self->set_edge_attribute($vertex, $n, $attr, $w);
 
             # Tally the weight of the vertex.
@@ -115,7 +106,6 @@ sub _from_hash {
     }
 
     # Set the weight of the graph node.
-    warn "Vertex $vertex $attr = $vertex_weight\n" if $DEBUG;
     $self->set_vertex_attribute($vertex, $attr, $vertex_weight);
 }
 
@@ -132,7 +122,6 @@ sub get_cost {
 
     # Default to weight.
     $attr ||= $WEIGHT;
-    warn "get_cost($v, $attr)\n" if $DEBUG;
 
     # Return the edge attribute if given a list.
     return $self->get_edge_attribute(@$v, $attr) || 0 if ref $v eq 'ARRAY';
@@ -210,7 +199,7 @@ sub path_cost {
     my $path_cost = 0;
 
     for my $i ( 0 .. @$path - 2 ) {
-        $path_cost += $self->get_cost( [ $path->[$i], $path->[ $i + 1 ] ] );
+        $path_cost += $self->get_cost( [ $path->[$i], $path->[ $i + 1 ] ], $attr );
     }
 
     return $path_cost;
@@ -230,7 +219,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.59
+version 0.5901
 
 =head1 SYNOPSIS
 
@@ -330,9 +319,6 @@ the overall dimension.
 
 Return the weight for the vertex or edge.
 
-A vertex is a numeric value.  An edge is an array reference with 2 elements.
-If no value is found, zero is returned.
-
 =head2 get_cost()
 
   $w = $gw->get_cost($vertex, $attribute);
